#ifndef __INHERITANCE_MATRIX_H__
#define __INHERITANCE_MATRIX_H__

#include "Pedigree.h"
#include "MathMatrix.h"
#include <vector>
#include <map>
#include <stdint.h>
#include <bitset>

using namespace std;

class Inheritance_Matrix
{
 public:
  Pedigree *ped;
  Family *fam;
  int famSize;
  int nFounders;
  int nNonFounders;
  int two_n;
  int two_n_minus_f;
  int two_f;
  int four_pow_f;
  std::vector<int> zero_bits_index;
  int zero_bits_checker;
  int *bit_checker;
  uint8_t *bit_count;
  std::map<int, uint8_t> bit_count_trans;
  uint8_t **founder_node_indicator;
  uint8_t ***geno_index;
  int nInherit_vector;
  unsigned int *inherit_vector;
  uint8_t **inherit_matrix;
  std::vector<std::bitset<sizeof(unsigned int)> > inherit_vector_bitset;
  std::vector<int> fa_traverse, mo_traverse;
  std::vector<int> founder_allele_index;
  std::map<int, vector<int> > offspring_traverse;

 public:
  Inheritance_Matrix();
  Inheritance_Matrix(Pedigree *);
  ~Inheritance_Matrix();

  void Initialize();
  void SetPedigree(Pedigree *);
  void SetFamily(Family *);
  void SetParentalTraverse();
  void SetZeroBits();
  void Count_Trans_Bits();
  int Count_Bits(unsigned int);
  void SetFounderNode();
  void MapFounderNode();
  void Create_Inheritance_Matrix();
  int Find_Founder_Node(int iv, int index);
  void Find_Founder_Node(int iv, uint8_t* iv_founder);
  void CalcFounderGenoMappingByIV(int iv, std::vector<std::vector<uint8_t> >& geno_index);
  void Print_Inheritance_Matrix();
  void Print_Inheritance_GenoIdx();
  void Print_Founder_Node_Indicator();
};


#endif
